searchData={"items":[{"type":"task","title":"mix rclex.gen.msgs","doc":"Generate codes of ROS 2 msg type\n\nBefore generating, specify msg types in config.exs is needed.\n\n```\nconfig :rclex, ros2_message_types: [\"std_msgs/msg/String\"]\n```\n\n> #### Info {: .info }\n> Be careful, ros2 msg type is case sensitive.","ref":"Mix.Tasks.Rclex.Gen.Msgs.html"},{"type":"task","title":"How to generate - mix rclex.gen.msgs","doc":"```\nmix rclex.gen.msgs\n```\n\nThis task assumes that the environment variable `ROS_DISTRO` is set\nand refers to the msg types from `/opt/ros/[ROS_DISTRO]/share`.\n\nWe can also specify explicitly as follows\n\n```\nmix rclex.gen.msgs --from /opt/ros/humble/share\n```","ref":"Mix.Tasks.Rclex.Gen.Msgs.html#module-how-to-generate"},{"type":"task","title":"How to clean - mix rclex.gen.msgs","doc":"```\nmix rclex.gen.msgs --clean\n```","ref":"Mix.Tasks.Rclex.Gen.Msgs.html#module-how-to-clean"},{"type":"task","title":"mix rclex.prep.ros2","doc":"Prepare ROS 2 resources under .ros2 directory.\n\n```\nmix rclex.prep.ros2 --arch ARCH\n```\n\nROS 2 resources will be prepared under .ros2.\n\nAn `--arch` option should be specified, option value is `arm64v8`, currently only supported.","ref":"Mix.Tasks.Rclex.Prep.Ros2.html"},{"type":"task","title":"Examples - mix rclex.prep.ros2","doc":"specify arch explicitly with `--arch` option\n\n```\nmix rclex.prep.ros2 --arch arm64v8\n```\n\nFor Nerves, `export MIX_TARGET=[TARGET]` is invoked properly, `--arch` option is not needed.\n\n```\nmix rclex.prep.ros2\n```","ref":"Mix.Tasks.Rclex.Prep.Ros2.html#module-examples"},{"type":"module","title":"Rclex","doc":"User API for `Elixir.Rclex`.","ref":"Rclex.html"},{"type":"function","title":"Rclex.publish/4","doc":"Publish message.\n\n- `topic_name` must lead with \"/\"","ref":"Rclex.html#publish/4"},{"type":"function","title":"opts - Rclex.publish/4","doc":"- `:namespace` must lead with \"/\". if not specified, the default is \"/\"","ref":"Rclex.html#publish/4-opts"},{"type":"function","title":"Examples - Rclex.publish/4","doc":"iex> alias Rclex.Pkgs.StdMsgs\n    iex> Rclex.publish(struct(StdMsgs.Msg.String, %{data: \"hello\"}), \"/chatter\", \"node\", namespace: \"/example\")\n    :ok\n    iex> Rclex.publish(struct(StdMsgs.Msg.String, %{data: \"hello\"}), \"/chatter\", \"node\")\n    {:error, :not_found}","ref":"Rclex.html#publish/4-examples"},{"type":"function","title":"Rclex.start_node/2","doc":"Start node.","ref":"Rclex.html#start_node/2"},{"type":"function","title":"opts - Rclex.start_node/2","doc":"- `:namespace` must lead with \"/\". if not specified, the default is \"/\"","ref":"Rclex.html#start_node/2-opts"},{"type":"function","title":"Examples - Rclex.start_node/2","doc":"iex> Rclex.start_node(\"node\", namespace: \"/example\")\n    :ok\n    iex> Rclex.start_node(\"node\", namespace: \"/example\")\n    {:error, :already_started}","ref":"Rclex.html#start_node/2-examples"},{"type":"function","title":"Rclex.start_publisher/4","doc":"Start publisher.\n\n- `topic_name` must lead with \"/\"","ref":"Rclex.html#start_publisher/4"},{"type":"function","title":"Examples - Rclex.start_publisher/4","doc":"iex> alias Rclex.Pkgs.StdMsgs\n    iex> Rclex.start_publisher(StdMsgs.Msg.String, \"/chatter\", \"node\", namespace: \"/example\")\n    :ok\n    iex> Rclex.start_publisher(StdMsgs.Msg.String, \"/chatter\", \"node\", namespace: \"/example\")\n    {:error, :already_started}","ref":"Rclex.html#start_publisher/4-examples"},{"type":"function","title":"Rclex.start_subscription/5","doc":"Start subscription.\n\n- `topic_name` must lead with \"/\"","ref":"Rclex.html#start_subscription/5"},{"type":"function","title":"opts - Rclex.start_subscription/5","doc":"- `:namespace` must lead with \"/\". if not specified, the default is \"/\"\n- `:qos` if not specified, applied the default which equals return of `Rclex.QoS.profile_default/0`","ref":"Rclex.html#start_subscription/5-opts"},{"type":"function","title":"Examples - Rclex.start_subscription/5","doc":"iex> alias Rclex.Pkgs.StdMsgs\n    iex> Rclex.start_subscription(&IO.inspect/1, StdMsgs.Msg.String, \"/chatter\", \"node\", namespace: \"/example\")\n    :ok\n    iex> Rclex.start_subscription(&IO.inspect/1, StdMsgs.Msg.String, \"/chatter\", \"node\", namespace: \"/example\")\n    {:error, :already_started}","ref":"Rclex.html#start_subscription/5-examples"},{"type":"function","title":"Rclex.start_timer/5","doc":"Start timer.","ref":"Rclex.html#start_timer/5"},{"type":"function","title":"opts - Rclex.start_timer/5","doc":"- `:namespace` must lead with \"/\". if not specified, the default is \"/\"","ref":"Rclex.html#start_timer/5-opts"},{"type":"function","title":"Examples - Rclex.start_timer/5","doc":"iex> Rclex.start_timer(1000, fn -> IO.inspect(\"tick\") end, \"tick\", \"node\", namespace: \"/example\")\n    :ok\n    iex> Rclex.start_timer(1000, fn -> IO.inspect(\"tick\") end, \"tick\", \"node\", namespace: \"/example\")\n    {:error, :already_started}","ref":"Rclex.html#start_timer/5-examples"},{"type":"function","title":"Rclex.stop_node/2","doc":"Stop node. And also stop the entities on the node, `publisher`, `subscription` and `timer`.","ref":"Rclex.html#stop_node/2"},{"type":"function","title":"opts - Rclex.stop_node/2","doc":"- `:namespace` must lead with \"/\". if not specified, the default is \"/\"","ref":"Rclex.html#stop_node/2-opts"},{"type":"function","title":"Examples - Rclex.stop_node/2","doc":"iex> Rclex.stop_node(\"node\", namespace: \"/example\")\n    :ok\n    iex> Rclex.stop_node(\"node\", namespace: \"/example\")\n    {:error, :not_found}","ref":"Rclex.html#stop_node/2-examples"},{"type":"function","title":"Rclex.stop_publisher/4","doc":"Stop publisher.\n\n- `topic_name` must lead with \"/\"","ref":"Rclex.html#stop_publisher/4"},{"type":"function","title":"opts - Rclex.stop_publisher/4","doc":"- `:namespace` must lead with \"/\". if not specified, the default is \"/\"","ref":"Rclex.html#stop_publisher/4-opts"},{"type":"function","title":"Examples - Rclex.stop_publisher/4","doc":"iex> alias Rclex.Pkgs.StdMsgs\n    iex> Rclex.stop_publisher(StdMsgs.Msg.String, \"/chatter\", \"node\", namespace: \"/example\")\n    :ok\n    iex> Rclex.stop_publisher(StdMsgs.Msg.String, \"/chatter\", \"node\", namespace: \"/example\")\n    {:error, :not_found}","ref":"Rclex.html#stop_publisher/4-examples"},{"type":"function","title":"Rclex.stop_subscription/4","doc":"Stop subscription.\n\n- `topic_name` must lead with \"/\"","ref":"Rclex.html#stop_subscription/4"},{"type":"function","title":"opts - Rclex.stop_subscription/4","doc":"- `:namespace` must lead with \"/\". if not specified, the default is \"/\"","ref":"Rclex.html#stop_subscription/4-opts"},{"type":"function","title":"Examples - Rclex.stop_subscription/4","doc":"iex> alias Rclex.Pkgs.StdMsgs\n    iex> Rclex.stop_subscription(StdMsgs.Msg.String, \"/chatter\", \"node\", namespace: \"/example\")\n    :ok\n    iex> Rclex.stop_subscription(StdMsgs.Msg.String, \"/chatter\", \"node\", namespace: \"/example\")\n    {:error, :not_found}","ref":"Rclex.html#stop_subscription/4-examples"},{"type":"function","title":"Rclex.stop_timer/3","doc":"Stop timer.","ref":"Rclex.html#stop_timer/3"},{"type":"function","title":"opts - Rclex.stop_timer/3","doc":"- `:namespace` must lead with \"/\". if not specified, the default is \"/\"","ref":"Rclex.html#stop_timer/3-opts"},{"type":"function","title":"Examples - Rclex.stop_timer/3","doc":"iex> Rclex.stop_timer(\"tick\", \"node\", namespace: \"/example\")\n    :ok\n    iex> Rclex.stop_timer(\"tick\", \"node\", namespace: \"/example\")\n    {:error, :not_found}","ref":"Rclex.html#stop_timer/3-examples"},{"type":"type","title":"Rclex.topic_name/0","doc":"`topic_name` must lead with \"/\".","ref":"Rclex.html#t:topic_name/0"},{"type":"module","title":"Rclex.MsgFuncs","doc":"","ref":"Rclex.MsgFuncs.html"},{"type":"module","title":"Rclex.QoS","doc":"Documentation for `Elixir.Rclex.QoS`.\n\nSee also [Quality of Service settings](https://docs.ros.org/en/humble/Concepts/Intermediate/About-Quality-of-Service-Settings.html) on ROS 2 Documentation.","ref":"Rclex.QoS.html"},{"type":"function","title":"Rclex.QoS.profile_default/0","doc":"Default QoS settings for publishers and subscriptions","ref":"Rclex.QoS.html#profile_default/0"},{"type":"function","title":"Rclex.QoS.profile_parameters/0","doc":"Parameters in ROS 2 are based on services, and as such have a similar profile. The difference is that parameters use a much larger queue depth so that requests do not get lost when, for example, the parameter client is unable to reach the parameter service server","ref":"Rclex.QoS.html#profile_parameters/0"},{"type":"function","title":"Rclex.QoS.profile_sensor_data/0","doc":"For sensor data, in most cases it’s more important to receive readings in a timely fashion, rather than ensuring that all of them arrive. That is, developers want the latest samples as soon as they are captured, at the expense of maybe losing some. For that reason the sensor data profile uses best effort reliability and a smaller queue size.","ref":"Rclex.QoS.html#profile_sensor_data/0"},{"type":"function","title":"Rclex.QoS.profile_services_default/0","doc":"In the same vein as publishers and subscriptions, services are reliable. It is especially important for services to use volatile durability, as otherwise service servers that re-start may receive outdated requests. While the client is protected from receiving multiple responses, the server is not protected from side-effects of receiving the outdated requests.","ref":"Rclex.QoS.html#profile_services_default/0"},{"type":"function","title":"Rclex.QoS.profile_system_default/0","doc":"This uses the RMW implementation’s default values for all of the policies. Different RMW implementations may have different defaults.","ref":"Rclex.QoS.html#profile_system_default/0"},{"type":"type","title":"Rclex.QoS.t/0","doc":"- `deadline`, `lifespan`, `liveliness_lease_duration` should be specified by float seconds.","ref":"Rclex.QoS.html#t:t/0"},{"type":"extras","title":"README","doc":"[![Hex version](https://img.shields.io/hexpm/v/rclex.svg \"Hex version\")](https://hex.pm/packages/rclex)\n[![API docs](https://img.shields.io/hexpm/v/rclex.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/rclex/readme.html)\n[![License](https://img.shields.io/hexpm/l/rclex.svg)](https://github.com/rclex/rclex/blob/main/LICENSE)\n[![ci-latest](https://github.com/rclex/rclex/actions/workflows/ci-latest.yml/badge.svg)](https://github.com/rclex/rclex/actions/workflows/ci-latest.yml)\n[![ci-all_version](https://github.com/rclex/rclex/actions/workflows/ci-all_version.yml/badge.svg)](https://github.com/rclex/rclex/actions/workflows/ci-all_version.yml)\n\n[日本語のREADME](README_ja.md)\n\n# Rclex\n\nRclex is a ROS 2 client library for the functional language [Elixir](https://elixir-lang.org/).\n\nThis library lets you perform basic ROS 2 behaviors by calling out from Elixir code into the RCL (ROS Client Library) API, which\nuses the ROS 2 common hierarchy.\n\nAdditionally, publisher-subscriber (PubSub) communication between nodes and associated callback functions are executed as Erlang lightweight processes.\nThis enables the creation of and communication between a large number of fault-tolerant\nnodes while suppressing memory load.","ref":"readme.html"},{"type":"extras","title":"What is ROS 2 - README","doc":"ROS 2 (Robot Operating System 2) is a state-of-the-art Robot development platform. In ROS 2, each functional\nunit is exposed as a node, and by combining these nodes you can create different robot applications. Additionally,\ncommunication between nodes uses a PubSub model where publishers and subscribers exchange information by specifying a\ncommon topic name.\n\nThe main benefits of ROS 2 are that the DDS (Data Distribution Service) protocol was adopted for\ncommunication, and the library was divided into a hierarchical structure.\nThis allows us to develop  ROS 2 client libraries in various languages and, of course, to build robot applications in Elixir.\n\nFor details on ROS 2, see [the official ROS 2 Documentation](https://docs.ros.org/en/rolling/index.html).","ref":"readme.html#what-is-ros-2"},{"type":"extras","title":"Recommended environment - README","doc":"","ref":"readme.html#recommended-environment"},{"type":"extras","title":"Native environment - README","doc":"The basic and recommended environment is where the host (development) and the target (operation) are the same.\n\nCurrently, we use the following environment as the main development target:\n\n- Ubuntu 22.04 LTS (Jammy Jellyfish)\n- ROS 2 Humble Hawksbill\n- Elixir 1.17.3-otp-27\n- Erlang/OTP 27.2.4\n\nWe highly recommend using [Humble Hawksbill](https://docs.ros.org/en/rolling/Releases/Release-Humble-Hawksbill.html) for ROS 2 LTS distribution.\nWe also confirmed the operation of this library with [Jazzy Jalisco](https://docs.ros.org/en/rolling/Releases/Release-Jazzy-Jalisco.html) on Ubuntu 24.04 LTS. See details in [PR#361](https://github.com/rclex/rclex/pull/361).\n\nWe do not support ROS 2 Distributions that have already reached EOL in the development of the latest version.\nThe last supported releases are as follows.\n\n- Foxy Fitzroy: [v0.11.3](https://github.com/rclex/rclex/releases/tag/v0.11.3)\n- Galactic Geochelone: [v0.11.3](https://github.com/rclex/rclex/releases/tag/v0.11.3)\n- Iron Irwini: [v0.11.3](https://github.com/rclex/rclex/releases/tag/v0.11.3)\n\nFor other environments used to check the operation of this library, please refer to [here](https://github.com/rclex/rclex_docker#available-versions-docker-tags).","ref":"readme.html#native-environment"},{"type":"extras","title":"Docker environment - README","doc":"The pre-built Docker images are available at [Docker Hub](https://hub.docker.com/r/rclex/rclex_docker).\nYou can also try the power of Rclex with it easily. Please check [\"Docker Environment\"](#Docker-environment) section for details.","ref":"readme.html#docker-environment"},{"type":"extras","title":"Nerves device (target) - README","doc":"`rclex` can be operated onto Nerves. In this case, you do not need to prepare the ROS 2 environment on the host computer to build Nerves project (so awesome!).\n\nPlease refer to [Use on Nerves](USE_ON_NERVES.md) section and [b5g-ex/rclex_on_nerves](https://github.com/b5g-ex/rclex_on_nerves) example repository for more details!","ref":"readme.html#nerves-device-target"},{"type":"extras","title":"Features - README","doc":"Currently, the Rclex API allows for the following:\n\n1. The ability to create a large number of publishers sending to the same topic.\n2. The ability to create large numbers of each combination of publishers, topics, and subscribers.\n\nYou can find the API documentation at [https://hexdocs.pm/rclex](https://hexdocs.pm/rclex).\n\nPlease refer [rclex/rclex_examples](https://github.com/rclex/rclex_examples) for the examples of usage along with the sample code.","ref":"readme.html#features"},{"type":"extras","title":"How to use - README","doc":"This section explains the quickstart for `rclex` in the native environment where ROS 2 and Elixir have been installed.","ref":"readme.html#how-to-use"},{"type":"extras","title":"Create the project - README","doc":"First of all, create the Mix project as a normal Elixir project.\n\n```\nmix new rclex_usage\ncd rclex_usage\n```","ref":"readme.html#create-the-project"},{"type":"extras","title":"Install rclex - README","doc":"`rclex` is [available in Hex](https://hex.pm/docs/publish).\n\nYou can install this package into your project\nby adding `rclex` to your list of dependencies in `mix.exs`:\n\n```elixir\n  defp deps do\n    [\n      ...\n      {:rclex, \"~> 0.12.0\"},\n      ...\n    ]\n  end\n```\n\nAfter that, execute `mix deps.get` into the project repository.\n\n```\nmix deps.get\n```","ref":"readme.html#install-rclex"},{"type":"extras","title":"Setup the ROS 2 environment - README","doc":"```\nsource /opt/ros/humble/setup.bash\n```","ref":"readme.html#setup-the-ros-2-environment"},{"type":"extras","title":"Configure ROS 2 message types you want to use - README","doc":"Rclex provides pub/sub-based topic communication using the message type defined in ROS 2. Please refer [here](https://docs.ros.org/en/humble/Concepts/About-ROS-Interfaces.html) for more details about message types in ROS 2.\n\nThe message types you want to use in your project can be specified in `ros2_message_types` in `config/config.exs`. \nMultiple message types can be specified separated by comma `,`.\n\nThe following `config/config.exs` example wants to use `String` type.\n\n```elixir\nimport Config\n\nconfig :rclex, ros2_message_types: [\"std_msgs/msg/String\"]\n```\n\nThen, execute the following Mix task to generate required definitions and files for message types.\n\n```\nmix rclex.gen.msgs\n```\n\nWhen editing `config/config.exs` to change the message types, do `mix rclex.gen.msgs` again.","ref":"readme.html#configure-ros-2-message-types-you-want-to-use"},{"type":"extras","title":"Write Rclex code - README","doc":"Now, you can acquire the environment for [Rclex API](https://hexdocs.pm/rclex/api-reference.html)! Of course, you can execute APIs on IEx directly.\n\nHere is the simplest implementation example `lib/rclex_usage.ex` that will publish the string to `/chatter` topic.\n\n```elixir\ndefmodule RclexUsage do\n  alias Rclex.Pkgs.StdMsgs\n\n  def publish_message do\n    Rclex.start_node(\"talker\")\n    Rclex.start_publisher(StdMsgs.Msg.String, \"/chatter\", \"talker\")\n\n    data = \"Hello World from Rclex!\"\n    msg = struct(StdMsgs.Msg.String, %{data: data})\n\n    IO.puts(\"Rclex: Publishing: #{data}\")\n    Rclex.publish(msg, \"/chatter\", \"talker\")\n  end\nend\n```\n\nPlease also check the examples for Rclex.\n\n- [rclex/rclex_examples](https://github.com/rclex/rclex_examples)","ref":"readme.html#write-rclex-code"},{"type":"extras","title":"Build and Execute - README","doc":"Build your application as follows.\n\n```\nmix compile\niex -S mix\n```\n\nOperate the following command on IEx.\n\n```\niex()> RclexUsage.publish_message\nRclex: Publishing: Hello World from Rclex!\n:ok\n```\n\nYou can confirm the above operation by subscribing with `ros2 topic echo` from the other terminal.\n\n```\n$ source /opt/ros/humble/setup.bash\n$ ros2 topic echo /chatter std_msgs/msg/String\ndata: Hello World from Rclex!\n---\n```","ref":"readme.html#build-and-execute"},{"type":"extras","title":"Enhance devepoment experience - README","doc":"This section describes the information mainly for developers.","ref":"readme.html#enhance-devepoment-experience"},{"type":"extras","title":"Docker environment - README","doc":"This repository provides a `docker compose` environment for library development with Docker.\n\nAs mentioned above, pre-built Docker images are available at [Docker Hub](https://hub.docker.com/r/rclex/rclex_docker), which can be used to easily try out Rclex.\nYou can set the environment variable `$RCLEX_DOCKER_TAG` to the version of the target environment. Please refer to [here](https://github.com/rclex/rclex_docker#available-versions-docker-tags) for the available environments.\n\n```\n# optional: set to the target environment (default `latest`)\nexport RCLEX_DOCKER_TAG=latest\n# create and start the container\ndocker compose up -d\n# execute the container (with the workdir where this repository is mounted)\ndocker compose exec -w /root/rclex rclex_docker /bin/bash\n# stop the container\ndocker compose down\n```\n\nIn [GitHub Actions](https://github.com/rclex/rclex/actions), we perform CI on multiple tool versions at Pull Requests by using these Docker environments. However, we cannot guarantee operation in all of these environments.","ref":"readme.html#docker-environment"},{"type":"extras","title":"Automatic execution of mix test, etc. - README","doc":"`mix test.watch` is introduced to automatically run unit test `mix test` and code formatting `mix format` every time the source code was edited.\n\n```\n$ mix test.watch\n# or, run on docker by following\n$ docker compose run --rm -w /root/rclex rclex_docker mix test.watch\n```","ref":"readme.html#automatic-execution-of-mix-test-etc"},{"type":"extras","title":"Confirmation of communication operation - README","doc":"To check the operation, especially for communication features of this library, we prepare [rclex/rclex_connection_tests](https://github.com/rclex/rclex_connection_tests) to test the communication with the nodes implemented with Rclcpp.\n\n```\ncd /path/to/yours\ngit clone https://github.com/rclex/rclex\ngit clone https://github.com/rclex/rclex_connection_tests\ncd /path/to/yours/rclex_connection_tests\n./run-all.sh\n```","ref":"readme.html#confirmation-of-communication-operation"},{"type":"extras","title":"Presentations - README","doc":"- Rclex on Nerves: a bare minimum runtime platform for ROS 2 nodes in Elixir\n  - [ROSCon 2023](https://roscon.ros.org/2023/)\n  - [Video](https://vimeo.com/879001529/b23eaacae8) | [SpeakerDeck](https://speakerdeck.com/takasehideki/rclex-on-nerves-a-bare-minimum-runtime-platform-for-ros-2-nodes-in-elixir)\n- On the way to achieve autonomous node communication in the Elixir ecosystem\n  - [Code BEAM America 2022](https://codebeamamerica.com/archives/CBA_2023/index.html) at 2022/11/03\n  - [Video](https://www.youtube.com/watch?v=Y4IASAU4Bjo) | [SpeakerDeck](https://speakerdeck.com/takasehideki/on-the-way-to-achieve-autonomous-node-communication-in-the-elixir-ecosystem)\n- Rclex: A Library for Robotics meet Elixir\n  - [Code BEAM America 2021](https://codesync.global/conferences/code-beam-sf-2021/) at 2021/11/05\n  - [Video](https://www.youtube.com/watch?v=9B5lQ3kQ_wI) | [SlideShare](https://www.slideshare.net/takasehideki/rclex-a-library-for-robotics-meet-elixir)","ref":"readme.html#presentations"},{"type":"extras","title":"Maintainers and developers (including past) - README","doc":"- [@takasehideki](https://github.com/takasehideki)\n- [@s-hosoai](https://github.com/s-hosoai)\n- [@pojiro](https://github.com/pojiro)\n- [@HiroiImanishi](https://github.com/HiroiImanishi)\n- [@kebus426](https://github.com/kebus426)\n- [@shiroro466](https://github.com/shiroro466)","ref":"readme.html#maintainers-and-developers-including-past"},{"type":"extras","title":"README_ja","doc":"[![Hex version](https://img.shields.io/hexpm/v/rclex.svg \"Hex version\")](https://hex.pm/packages/rclex)\n[![API docs](https://img.shields.io/hexpm/v/rclex.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/rclex/readme.html)\n[![License](https://img.shields.io/hexpm/l/rclex.svg)](https://github.com/rclex/rclex/blob/main/LICENSE)\n[![ci-latest](https://github.com/rclex/rclex/actions/workflows/ci-latest.yml/badge.svg)](https://github.com/rclex/rclex/actions/workflows/ci-latest.yml)\n[![ci-all_version](https://github.com/rclex/rclex/actions/workflows/ci-all_version.yml/badge.svg)](https://github.com/rclex/rclex/actions/workflows/ci-all_version.yml)\n\n注：READMEは[英語版](README.md)が常に最新かつ確実です．\n\n# Rclex [Ja]\n\n関数型言語[Elixir](https://elixir-lang.org/)によるROS 2クライアントライブラリです．\n\nROS 2共通階層であるRCL（ROS Client Library）APIをElixirコードから呼び出すことでROS 2の基本的な振る舞いを実現しています．\n\nまた，ノード間の出版購読通信およびそれに付随するコールバック関数をErlangの軽量プロセスに実行させるようにしています．\nこれにより，メモリへの負荷を抑えつつ，また耐障害性を高めてノードを大量に生成，通信させることが可能になっています．","ref":"readme_ja.html"},{"type":"extras","title":"ROS 2とは - README_ja","doc":"ROS（Robot Operating System）というロボット開発を支援するプラットフォームの次世代版です．\nROS 2では，機能単位はノードとして表現され，ノードを複数組み合わせてさまざまな所望のロボットアプリケーションが作成できます．\nまたノード間通信には出版購読通信が主に用いられ，パブリッシャとサブスクライバがトピックという名前でデータを識別してやりとりしています．\n\nROS 2の主な貢献として，通信にDDS（Data Distribution Service）プロトコルが採用されたこと，そしてライブラリが階層構造に分けられたことです．\nこれによって，様々な言語でROS 2クライアントライブラリを開発できるようになり，もちろんElixirでもロボットアプリケーションを開発できるようになりました．\n\n詳しくは[ROS 2の公式ドキュメント](https://docs.ros.org/en/rolling/index.html)を参照ください．","ref":"readme_ja.html#ros-2%E3%81%A8%E3%81%AF"},{"type":"extras","title":"対象とする環境 - README_ja","doc":"","ref":"readme_ja.html#%E5%AF%BE%E8%B1%A1%E3%81%A8%E3%81%99%E3%82%8B%E7%92%B0%E5%A2%83"},{"type":"extras","title":"ネイティブ環境 - README_ja","doc":"基本的で推奨される環境は，ホスト（開発環境）とターゲット（実行環境）が同一のものです．\n\n現在，下記の環境を主な対象として開発を進めています．\n\n- Ubuntu 22.04 LTS (Jammy Jellyfish)\n- ROS 2 Humble Hawksbill\n- Elixir 1.17.3-otp-27\n- Erlang/OTP 27.2.4\n\nROS 2には長期サポート版（LTS）である[Humble Hawksbill](https://docs.ros.org/en/humble/Releases/Release-Humble-Hawksbill.html)の利用を強く推奨します．\nUbuntu 24.04 LTS上での[Jazzy Jalisco](https://docs.ros.org/en/rolling/Releases/Release-Jazzy-Jalisco.html)との本ライブラリの動作確認も行っています．詳細は[PR#361](https://github.com/rclex/rclex/pull/361)を参照ください．\n\n短期サポート版（STS）のIronは，実験的なサポートでありネイティブ環境での基本的な動作のみを確認しています．対応状況の詳細は[Issue#228](https://github.com/rclex/rclex/issues/228#issuecomment-1715293177)を確認してください．\n\nすでにEOLに達しているROS 2 Distributionsは，最新版に向けた開発ではサポートしていません．サポートを行っていた最終のリリース番号は次のとおりです．\n\n- Foxy Fitzroy: [v0.11.3](https://github.com/rclex/rclex/releases/tag/v0.11.3)\n- Galactic Geochelone: [v0.11.3](https://github.com/rclex/rclex/releases/tag/v0.11.3)\n- Iron Irwini: [v0.11.3](https://github.com/rclex/rclex/releases/tag/v0.11.3)\n\n動作検証の対象としている環境は[こちら](https://github.com/rclex/rclex_docker#available-versions-docker-tags)を参照してください．","ref":"readme_ja.html#%E3%83%8D%E3%82%A4%E3%83%86%E3%82%A3%E3%83%96%E7%92%B0%E5%A2%83"},{"type":"extras","title":"Docker環境 - README_ja","doc":"[Docker Hub](https://hub.docker.com/r/rclex/rclex_docker)にてビルド済みのDockerイメージを公開しており，これを用いてRclexを簡単に試行することもできます．\n詳細は[「Docker環境の利用」](#Docker環境の利用)のセクションを参照してください．","ref":"readme_ja.html#docker%E7%92%B0%E5%A2%83"},{"type":"extras","title":"Nervesデバイス（ターゲット） - README_ja","doc":"`rclex` はNerves上での実行も可能です．この場合，ホスト環境にはROS 2環境を導入する必要はありません．\n\n詳細は[Use on Nerves](USE_ON_NERVES.md)のセクションおよび[b5g-ex/rclex_on_nerves](https://github.com/b5g-ex/rclex_on_nerves)のリポジトリによる例を参照してください．","ref":"readme_ja.html#nerves%E3%83%87%E3%83%90%E3%82%A4%E3%82%B9-%E3%82%BF%E3%83%BC%E3%82%B2%E3%83%83%E3%83%88"},{"type":"extras","title":"機能 - README_ja","doc":"現時点では以下のことができるようにRclex APIを提供しています．\n1. 同一トピックに対して，複数のパブリッシャおよびサブスクライバを大量に作成できる．\n2. パブリッシャ，トピック，サブスクライバが1つずつのペアを大量に作成できる．\n\nAPIドキュメントは[https://hexdocs.pm/rclex](https://hexdocs.pm/rclex)をご参照ください．\n\n使用例は[rclex/rclex_examples](https://github.com/rclex/rclex_examples)を参照してください．サンプルコードとともに使い方を記しています．","ref":"readme_ja.html#%E6%A9%9F%E8%83%BD"},{"type":"extras","title":"使用方法 - README_ja","doc":"ここでは，ROS 2およびElixirの動作環境がインストール済みであるネイティブ環境での`rclex`の使用方法を示します．","ref":"readme_ja.html#%E4%BD%BF%E7%94%A8%E6%96%B9%E6%B3%95"},{"type":"extras","title":"プロジェクトの作成 - README_ja","doc":"通常のElixirプロジェクトと同様に作成します．\n\n```\nmix new rclex_usage\ncd rclex_usage\n```","ref":"readme_ja.html#%E3%83%97%E3%83%AD%E3%82%B8%E3%82%A7%E3%82%AF%E3%83%88%E3%81%AE%E4%BD%9C%E6%88%90"},{"type":"extras","title":"rclexのインストール - README_ja","doc":"`rclex` は[Hexパッケージとして公開](https://hex.pm/docs/publish)しています．\n\n`mix.exs` の依存関係に `rclex` を追加することで，ご自身のプロジェクトにて使用することができます．\n\n```elixir\n  defp deps do\n    [\n      ...\n      {:rclex, \"~> 0.12.0\"},\n      ...\n    ]\n  end\n```\n\n上記を追加後，プロジェクトのディレクトリ内で `mix deps.get` を実行してください．\n\n```\nmix deps.get\n```","ref":"readme_ja.html#rclex%E3%81%AE%E3%82%A4%E3%83%B3%E3%82%B9%E3%83%88%E3%83%BC%E3%83%AB"},{"type":"extras","title":"ROS 2の環境設定 - README_ja","doc":"```\nsource /opt/ros/humble/setup.bash\n```","ref":"readme_ja.html#ros-2%E3%81%AE%E7%92%B0%E5%A2%83%E8%A8%AD%E5%AE%9A"},{"type":"extras","title":"メッセージの型の設定 - README_ja","doc":"Rclexでは，ROS 2において定義されるメッセージの型を利用して出版購読型のトピック通信を行うことができます．ROS 2におけるメッセージの型については[こちら](https://docs.ros.org/en/humble/Concepts/About-ROS-Interfaces.html)を参照してください．\n\nプロジェクトで使用したいメッセージの型は，`config/config.exs` における `ros2_message_types` で指定します．コンマ区切り `,` で複数の型を指定することもできます．\n\nここでは `String` 型を使用したい `config/config.exs` の例を示します．\n\n```elixir\nimport Config\n\nconfig :rclex, ros2_message_types: [\"std_msgs/msg/String\"]\n```\n\nその後，次のMixタスクを実行し，メッセージの型を使用するために必要な定義とファイル群を自動生成します．\n\n```\nmix rclex.gen.msgs\n```\n\n`config/config.exs`を編集してメッセージの型を変更したときは, `mix rclex.gen.msgs`を再度実行してください．","ref":"readme_ja.html#%E3%83%A1%E3%83%83%E3%82%BB%E3%83%BC%E3%82%B8%E3%81%AE%E5%9E%8B%E3%81%AE%E8%A8%AD%E5%AE%9A"},{"type":"extras","title":"コードの実装 - README_ja","doc":"これで Rclex を使用する準備が整いました！  \nもちろんIEx上で[RclexのAPI](https://hexdocs.pm/rclex/api-reference.html)を直接実行することもできます．\n\nここでは，最も単純なコードを対象として，プロジェクトの実装例を示します．\n次のコード `lib/rclex_usage.ex` は，`String`型のトピック `/chatter` に対して文字列を出版する処理を示しています．\n\n```elixir\ndefmodule RclexUsage do\n  alias Rclex.Pkgs.StdMsgs\n\n  def publish_message do\n    Rclex.start_node(\"talker\")\n    Rclex.start_publisher(StdMsgs.Msg.String, \"/chatter\", \"talker\")\n\n    data = \"Hello World from Rclex!\"\n    msg = struct(StdMsgs.Msg.String, %{data: data})\n\n    IO.puts(\"Rclex: Publishing: #{data}\")\n    Rclex.publish(msg, \"/chatter\", \"talker\")\n  end\nend\n```\n\nこの他の実装例は，下記も参照してください．\n\n- [rclex/rclex_examples](https://github.com/rclex/rclex_examples)","ref":"readme_ja.html#%E3%82%B3%E3%83%BC%E3%83%89%E3%81%AE%E5%AE%9F%E8%A3%85"},{"type":"extras","title":"ビルドと実行 - README_ja","doc":"次のようにアプリケーションをビルドしてください．\n\n```\nmix compile\niex -S mix\n```\n\nIEx上で次のように実行してください．\n\n```\niex()> RclexUsage.publish_message\nRclex: Publishing: Hello World from Rclex!\n:ok\n```\n\nこのメッセージの出版結果は，ROS 2コマンド`ros2 topic echo`によって購読して確認できます．\n\n```\n$ source /opt/ros/humble/setup.bash\n$ ros2 topic echo /chatter std_msgs/msg/String\ndata: Hello World from Rclex!\n---\n```","ref":"readme_ja.html#%E3%83%93%E3%83%AB%E3%83%89%E3%81%A8%E5%AE%9F%E8%A1%8C"},{"type":"extras","title":"開発の円滑化 - README_ja","doc":"本セクションでは主に開発者向けの情報を示します．","ref":"readme_ja.html#%E9%96%8B%E7%99%BA%E3%81%AE%E5%86%86%E6%BB%91%E5%8C%96"},{"type":"extras","title":"Docker環境の利用 - README_ja","doc":"本リポジトリでは，Dockerでライブラリ開発を進めるための`docker compose`による環境を提供しています．\n\n前述の通り[Docker Hub](https://hub.docker.com/r/rclex/rclex_docker)にてビルド済みのDockerイメージを公開しており，これを用いることでRclexを簡単に試行できます．\n環境変数 `$RCLEX_DOCKER_TAG` にて対象とする実行環境のバージョンを設定できます．設定可能な実行環境は[こちら](https://github.com/rclex/rclex_docker#available-versions-docker-tags)を参照してください．\n\n```\n# optional: 実行環境の設定（デフォルトは`latest`）\nexport RCLEX_DOCKER_TAG=latest\n# コンテナを作成して起動\ndocker compose up -d\n# コンテナの実行（本リポジトリのマウントポイントを作業ディレクトリに）\ndocker compose exec -w /root/rclex rclex_docker /bin/bash\n# コンテナの終了\ndocker compose down\n```\n\n[GitHub Actions](https://github.com/rclex/rclex/actions)では，これらのDocker環境を利用して，複数のツールバージョンでのCIを実行しています．ただし，これら全ての環境での動作保証には対応できません．","ref":"readme_ja.html#docker%E7%92%B0%E5%A2%83%E3%81%AE%E5%88%A9%E7%94%A8"},{"type":"extras","title":"mix test等の自動実行 - README_ja","doc":"`mix test.watch` を導入しており，ソースコードの編集時毎に，単体テスト `mix test` やコード整形 `mix format` を自動実行できます．\n\n```\n$ mix test.watch\n# または docker で動作させるには\n$ docker compose run --rm -w /root/rclex rclex_docker mix test.watch\n```","ref":"readme_ja.html#mix-test%E7%AD%89%E3%81%AE%E8%87%AA%E5%8B%95%E5%AE%9F%E8%A1%8C"},{"type":"extras","title":"通信に関する動作確認 - README_ja","doc":"特にノード間通信に関する動作確認として，[rclex/rclex_connection_tests](https://github.com/rclex/rclex_connection_tests)を用いてRclcppで実装されたノードとの通信に関するテストを実施しています．\n\n```\ncd /path/to/yours\ngit clone https://github.com/rclex/rclex\ngit clone https://github.com/rclex/rclex_connection_tests\ncd /path/to/yours/rclex_connection_tests\n./run-all.sh\n```","ref":"readme_ja.html#%E9%80%9A%E4%BF%A1%E3%81%AB%E9%96%A2%E3%81%99%E3%82%8B%E5%8B%95%E4%BD%9C%E7%A2%BA%E8%AA%8D"},{"type":"extras","title":"主な管理者と開発者（過去分も含む） - README_ja","doc":"- [@takasehideki](https://github.com/takasehideki)\n- [@s-hosoai](https://github.com/s-hosoai)\n- [@pojiro](https://github.com/pojiro)\n- [@HiroiImanishi](https://github.com/HiroiImanishi)\n- [@kebus426](https://github.com/kebus426)\n- [@shiroro466](https://github.com/shiroro466)","ref":"readme_ja.html#%E4%B8%BB%E3%81%AA%E7%AE%A1%E7%90%86%E8%80%85%E3%81%A8%E9%96%8B%E7%99%BA%E8%80%85-%E9%81%8E%E5%8E%BB%E5%88%86%E3%82%82%E5%90%AB%E3%82%80"},{"type":"extras","title":"Use on Nerves","doc":"# Use on Nerves\n\n`rclex` can be operated onto Nerves. In this case, you do not need to prepare the ROS 2 environment on the host computer to build Nerves project (so awesome!).\n\nThis doc shows the steps on how to use Rclex on Nerves from scratch.\n\nWe have also published the Nerves project that has been prepared and includes example code at [b5g-ex/rclex_on_nerves](https://github.com/b5g-ex/rclex_on_nerves). Please also refer to this repository.","ref":"use_on_nerves.html"},{"type":"extras","title":"Supported Targets - Use on Nerves","doc":"Currently, we have confirmed the following boards as the Nerves device that can operate Rclex (good luck to get one!).\n\n| board | tag | arch | support for nerves_system |\n| :--- | :--- | :---| :---|\n| [Raspberry Pi 4](https://github.com/nerves-project/nerves_system_rpi4) | rpi4 | arm64v8 | Officially supported, recommended |\n| [BeagleBone Green](https://github.com/nerves-project/nerves_system_bbb) | bbb | arm32v7 | Officially supported |\n| [Kria KR260](https://github.com/b5g-ex/nerves_system_kr260) | kr260 | arm64v8 | Third-party supported |\n| [ODYSSEY - STM32MP157C](https://github.com/b5g-ex/nerves_system_stm32mp157c_odyssey) | stm32mp157c_odyssey | arm32v7 | Third-party supported |\n| [F3RP70 (e-RT3 Plus)](https://github.com/pojiro/nerves_system_f3rp70) | f3rp70 | arm32v7 | Third-party supported |\n\nThe below is the supported ROS 2 distribution and architecture that can operate rclex_on_nerves.\nThe \"support\" colomn refers to its status of official support as the ROS 2 distribution.\n\n| `ROS_DISTRO` | arm64v8 | arm32v7 | support |\n| :--- | :--- | :---| :---|\n| humble | ○ | ○ | LTS until May 2027 |\n| galactic | ○ | - | until [v0.11.3](https://github.com/rclex/rclex/releases/tag/v0.11.3) |\n| foxy | ○ | ○ | until [v0.11.3](https://github.com/rclex/rclex/releases/tag/v0.11.3) |","ref":"use_on_nerves.html#supported-targets"},{"type":"extras","title":"Preliminaries - Use on Nerves","doc":"During the procedure for Rclex on Nerves, the docker command is used to copy the necessary directory in `mix rclex.prep.ros2`.\nPlease install [Docker Desktop](https://docs.docker.com/desktop/) or [Docker Engine](https://docs.docker.com/engine/), and start it first.  \nAnd also, Rclex on Nerves will deploy an docker container for arm64 arch. If you want to operate this project by Docker Engine on other platforms (x86_64), you need to install qemu as the follows: `sudo apt-get install qemu binfmt-support qemu-user-static`\n\nIt should be noted that do not perform the following steps inside a docker container.  \nOnce again, they can be operated even if ROS 2 is not installed on the host machine!","ref":"use_on_nerves.html#preliminaries"},{"type":"extras","title":"Procedure - Use on Nerves","doc":"> #### Target device {: .neutral }\n>\n> The following steps assume that `rpi4` and `arm64v8` will be used as the target Nerves device.\n> You may change the values of `MIX_TARGET` and `--arch` to match the \"tag\" and \"arch\" columns on the supported target list according to the board you want to use.","ref":"use_on_nerves.html#procedure"},{"type":"extras","title":"Create Nerves Project - Use on Nerves","doc":"```\nmix nerves.new rclex_usage_on_nerves --target rpi4\ncd rclex_usage_on_nerves\nexport MIX_TARGET=rpi4\nmix deps.get\n```\n\n> #### Note {: .warning }\n>\n> If `mix deps.get` failed, you may need to create SSH key and configure config/target.exs.","ref":"use_on_nerves.html#create-nerves-project"},{"type":"extras","title":"Install rclex - Use on Nerves","doc":"`rclex` is [available in Hex](https://hex.pm/docs/publish).\n\nYou can install this package into your project\nby adding `rclex` to your list of dependencies in `mix.exs`:\n\n```elixir\n  defp deps do\n    [\n      ...\n      {:rclex, \"~> 0.12.0\"},\n      ...\n    ]\n  end\n```\n\nAfter that, execute `mix deps.get` into the project repository.\n\n```\nmix deps.get\n```","ref":"use_on_nerves.html#install-rclex"},{"type":"extras","title":"Prepare ROS 2 resources - Use on Nerves","doc":"> #### Note {: .info }\n>\n> In the following steps, Humble Hawksbill (`humble`) is assumed to be used as `ROS_DISTRO` (strongly recommend to use).\n> If you want to use other ROS 2 distributions, you need to replace it appropriately in the subsequent steps. Note that these have already reached EOL.\n\nThe following command extracts the ROS 2 Docker image and copies resources required for Rclex to the Nerves file system.\nYou may change the value of `--arch` according to the architecture of your target board (see the \"arch\" column on the supported target list)\n\n```\nexport ROS_DISTRO=humble\nmix rclex.prep.ros2 --arch arm64v8\n```\n\n> #### Note {: .warning }\n>\n> The following warning messages will occur at several times when the host and target architectures are different. These can be ignored.\n> > WARNING: The requested image's platform (linux/arm/v7) does not match the detected host platform (linux/amd64) and no specific platform was requested","ref":"use_on_nerves.html#prepare-ros-2-resources"},{"type":"extras","title":"Configure ROS 2 message types you want to use - Use on Nerves","doc":"Rclex provides pub/sub based topic communication using the message type defined in ROS 2. Please refer [here](https://docs.ros.org/en/humble/Concepts/About-ROS-Interfaces.html) for more details about message types in ROS 2.\n\nThe message types you want to use in your project can be specified in `ros2_message_types` in `config/config.exs`. \nMultiple message types can be specified separated by comma `,`.\n\nThe following `config/config.exs` example wants to use `String` type.\n\n```elixir\nconfig :rclex, ros2_message_types: [\"std_msgs/msg/String\"]\n```\n\nThen, execute the following Mix task to generate required definitions and files for message types.\n\n```\nmix rclex.gen.msgs\n```\n\nIf you want to change the message types in config, do `mix rclex.gen.msgs` again.","ref":"use_on_nerves.html#configure-ros-2-message-types-you-want-to-use"},{"type":"extras","title":"Copy erlinit.config to rootfs_overlay/etc and add LD_LIBRARY_PATH - Use on Nerves","doc":"Copy erlinit.config from `nerves_system_***`.\n\n```\ncp deps/nerves_system_rpi4/rootfs_overlay/etc/erlinit.config rootfs_overlay/etc\n```\n\nAdd LD_LIBRARY_PATH line like following.  \n`ROS_DISTRO` should be written directly such as `humble`, as the below.\n\n```\n# Enable UTF-8 filename handling in Erlang and custom inet configuration\n-e LANG=en_US.UTF-8;LANGUAGE=en;ERL_INETRC=/etc/erl_inetrc\n\n# Enable crash dumps (set ERL_CRASH_DUMP_SECONDS=0 to disable)\n-e ERL_CRASH_DUMP=/root/erl_crash.dump;ERL_CRASH_DUMP_SECONDS=5\n\n# add for ROS 2 (rclex_on_nerves)\n-e LD_LIBRARY_PATH=/opt/ros/humble/lib\n```\n\n> #### Why add LD_LIBRARY_PATH explicitly {: .info }\n>\n> ROS 2 needs the path. If you want to know the details, please read following\n>\n> - https://github.com/ros-tooling/cross_compile/issues/363\n> - https://github.com/ros2/rcpputils/pull/122","ref":"use_on_nerves.html#copy-erlinit-config-to-rootfs_overlay-etc-and-add-ld_library_path"},{"type":"extras","title":"Write Rclex code - Use on Nerves","doc":"Now, you can acquire the environment for [Rclex API](https://hexdocs.pm/rclex/api-reference.html)! Of course, you can execute APIs on IEx directly.\n\nHere is the simplest implementation example `lib/rclex_usage_on_nerves.ex` that will publish the string to `/chatter` topic.\n\n```elixir\ndefmodule RclexUsageOnNerves do\n  alias Rclex.Pkgs.StdMsgs\n\n  def publish_message do\n    Rclex.start_node(\"talker\")\n    Rclex.start_publisher(StdMsgs.Msg.String, \"/chatter\", \"talker\")\n\n    data = \"Hello World from Rclex!\"\n    msg = struct(StdMsgs.Msg.String, %{data: data})\n\n    IO.puts(\"Rclex: Publishing: #{data}\")\n    Rclex.publish(msg, \"/chatter\", \"talker\")\n  end\nend\n```\n\nPlease also check the examples for Rclex.\n- [rclex/rclex_examples](https://github.com/rclex/rclex_examples)\n- [b5g-ex/rclex_on_nerves](https://github.com/b5g-ex/rclex_on_nerves)","ref":"use_on_nerves.html#write-rclex-code"},{"type":"extras","title":"Create fw, and burn (or, upload) - Use on Nerves","doc":"```\nmix firmware\nmix burn # or, mix upload\n```","ref":"use_on_nerves.html#create-fw-and-burn-or-upload"},{"type":"extras","title":"Execute - Use on Nerves","doc":"Connect the Nerves device via ssh.\n\n```\nssh nerves.local\n```\n\nOperate the following command on IEx.\n\n```\niex()> RclexUsageOnNerves.publish_message\nRclex: Publishing: Hello World from Rclex!\n:ok\n```\n\nYou can confirm the above operation by subscribing with `ros2 topic echo` on the machine where ROS 2 env has been installed.\n\n```\n$ source /opt/ros/humble/setup.bash\n$ ros2 topic echo /chatter std_msgs/msg/String\ndata: Hello World from Rclex!\n---\n```","ref":"use_on_nerves.html#execute"},{"type":"extras","title":"CHANGELOG","doc":"# CHANGELOG","ref":"changelog.html"},{"type":"extras","title":"v0.12.0 on 04 Mar 2025 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.11.3...v0.12.0\n\n* New features:\n  * Support jazzy by @pojiro in https://github.com/rclex/rclex/pull/361\n  * Remove old distro's dependent code that has already reached EOL by @takasehideki in https://github.com/rclex/rclex/pull/365\n  * Bump supported versions and CI targets by @takasehideki in https://github.com/rclex/rclex/pull/364\n  * Reapply git_hooks (v0.8.0 that has been addressed about path issue) by @takasehideki in https://github.com/rclex/rclex/pull/366\n* Code Improvements/Fixes:\n  * Patch for #366 by @pojiro in https://github.com/rclex/rclex/pull/368\n* Bumps: none\n* Note in this release: \n  * Please welecome Jazzy Jalisco to our supported ROS 2 LTS distribution!! :tada:\n  * We decided to stop the support for old distributions (Foxy, Galactic and Iron) which have already reached EOL because of the concentrataion of our development resources in the future. If you want to use these distributions, please consider to employ v0.11.3 or earlier (see [#PR365](https://github.com/rclex/rclex/pull/365)).","ref":"changelog.html#v0-12-0-on-04-mar-2025"},{"type":"extras","title":"v0.11.3 on 25 Feb 2025 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.11.2...v0.11.3\n\n* New features: none\n* Code Improvements/Fixes: none\n* Bumps: \n  * Bump nimble_parsec from 1.4.0 to 1.4.2 by @dependabot in https://github.com/rclex/rclex/pull/360\n  * Bump credo from 1.7.8 to 1.7.11 by @dependabot in https://github.com/rclex/rclex/pull/358\n  * Bump ex_doc from 0.34.2 to 0.36.1 by @dependabot in https://github.com/rclex/rclex/pull/357\n  * Bump elixir_make from 0.8.4 to 0.9.0 by @dependabot in https://github.com/rclex/rclex/pull/353\n  * Bump dialyxir from 1.4.4 to 1.4.5 by @dependabot in https://github.com/rclex/rclex/pull/354\n  * Manually update of deps by `mix deps.update --all` by @takasehideki in https://github.com/rclex/rclex/pull/362\n* Note in this release: \n  * This may be the final release to support old ROS distribution, e.g., Foxy, Galactic and Iron.\n  * Support for Jazzy is available in `main` branch. We'd like to release this ASAP (ref: https://github.com/rclex/rclex/pull/361)","ref":"changelog.html#v0-11-3-on-25-feb-2025"},{"type":"extras","title":"v0.11.2 on 13 Oct 2024 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.11.1...v0.11.2\n\n* New features: none\n* Code Improvements/Fixes:\n  * Optimize binary copy for ROS2 rcl uint8 array by @pojiro in https://github.com/rclex/rclex/pull/348\n    * Reported and confirmed by @mlainez. Thank you.\n* Bumps: none\n* Note in this release: none","ref":"changelog.html#v0-11-2-on-13-oct-2024"},{"type":"extras","title":"v0.11.1 on 03 Oct 2024 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.11.0...v0.11.1\n\n* New features: none\n* Code Improvements/Fixes:\n  * Fix UnicodeConversionError caused by treating a uint8 array as Unicode by @pojiro in https://github.com/rclex/rclex/pull/345\n* Bumps:\n  * Bump dialyxir from 1.4.3 to 1.4.4 by @dependabot in https://github.com/rclex/rclex/pull/343\n  * Bump credo from 1.7.7 to 1.7.8 by @dependabot in https://github.com/rclex/rclex/pull/342\n  * Bump ex_doc from 0.34.1 to 0.34.2 by @dependabot in https://github.com/rclex/rclex/pull/335\n* Note in this release:\n  * We deeply apologize,,, v0.11.0 could not be released on hex.pm because API key had revoked for GHA,,,","ref":"changelog.html#v0-11-1-on-03-oct-2024"},{"type":"extras","title":"v0.11.0 on 07 Jul 2024 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.10.1...v0.11.0\n\n* New features: none\n* Code Improvements/Fixes:\n  * Enhance msgs by @pojiro and @FelixPe in https://github.com/rclex/rclex/pull/325\n    * Especially, Use binary type for uint8[] in msgs (originally suggested by @FelixPe in #316)\n* Bumps:\n  * Bump elixir_make from 0.8.3 to 0.8.4 by @dependabot in https://github.com/rclex/rclex/pull/327\n  * Bump benchee from 1.3.0 to 1.3.1 by @dependabot in https://github.com/rclex/rclex/pull/328\n  * Bump credo from 1.7.6 to 1.7.7 by @dependabot in https://github.com/rclex/rclex/pull/329\n  * Bump ex_doc from 0.33.0 to 0.34.1 by @dependabot in https://github.com/rclex/rclex/pull/331\n* Note in this release:\n  * As described above, this release includes the breaking change to handle uint8[] in msgs as binary type in Elixir, contributed by @pojiro and @FelixPe :raised_hands:","ref":"changelog.html#v0-11-0-on-07-jul-2024"},{"type":"extras","title":"v0.10.1 on 23 May 2024 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.10.0...v0.10.1\n\n* New features:\n  * Use `rcl_subscription_set_on_new_message_callback` by @pojiro and @FelixPe in https://github.com/rclex/rclex/pull/317\n* Code Improvements/Fixes:\n  * restore rclex_connection_tests by @takasehideki in https://github.com/rclex/rclex/pull/305\n  * bump CI targets according to https://github.com/rclex/rclex_docker/pull/17 by @takasehideki in https://github.com/rclex/rclex/pull/308\n  * bump tool-versions to follow `latest` by @takasehideki in https://github.com/rclex/rclex/pull/310\n  * Minor fixes by @pojiro in https://github.com/rclex/rclex/pull/319\n* Bumps:\n  * Bump mix_test_watch from 1.1.2 to 1.2.0 by @dependabot in https://github.com/rclex/rclex/pull/295\n  * Bump elixir_make from 0.7.8 to 0.8.3 by @dependabot in https://github.com/rclex/rclex/pull/309\n  * Bump benchee from 1.1.0 to 1.3.0 by @dependabot in https://github.com/rclex/rclex/pull/304\n  * Bump ex_doc from 0.31.1 to 0.31.2 by @dependabot in https://github.com/rclex/rclex/pull/296\n  * Bump credo from 1.7.5 to 1.7.6 by @dependabot in https://github.com/rclex/rclex/pull/321\n  * Bump ex_doc from 0.31.2 to 0.33.0 by @dependabot in https://github.com/rclex/rclex/pull/323\n* Note in this release: none","ref":"changelog.html#v0-10-1-on-23-may-2024"},{"type":"extras","title":"v0.10.0 on 19 Mar 2024 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.9.3...v0.10.0\n\n**Almost Everything has been breaking changed!!**\n\nAccording to the knowledge acquired by our R&D experience to date, the internal structure and design of this library have been significantly revised.\nThe API specification has also been completely redesigned.\nFrom these changes, it is appropriate to say that we have almost reimplemented this library scratch in https://github.com/rclex/rclex/pull/286, leading by the awesome alchemist @pojiro :D\n\nIt should be noted that the API in this release is not compatible with v0.9 or earlier, so please be careful when updating this library used in your applications.\n\nWe will investigate after this release whether existing [Issues](https://github.com/rclex/rclex/issues) have been resolved by this historical improvement.","ref":"changelog.html#v0-10-0-on-19-mar-2024"},{"type":"extras","title":"v0.9.3 on 23 Feb 2024 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.9.2...v0.9.3\n\n* New features: none\n* Code Improvements/Fixes:\n  * add section of presentations (Code BEAM America 2021 and 2022) by @takasehideki in https://github.com/rclex/rclex/pull/262\n* Bumps:\n  * Bump dialyxir from 1.4.1 to 1.4.3 by @dependabot in https://github.com/rclex/rclex/pull/279\n  * Bump ex_doc from 0.30.6 to 0.31.1 by @dependabot in https://github.com/rclex/rclex/pull/283\n  * Bump elixir_make from 0.7.7 to 0.7.8 by @dependabot in https://github.com/rclex/rclex/pull/287\n  * Bump credo from 1.7.1 to 1.7.3 by @dependabot in https://github.com/rclex/rclex/pull/282\n  * Bump mix_test_watch from 1.1.1 to 1.1.2 by @dependabot in https://github.com/rclex/rclex/pull/288\n  * Bump credo from 1.7.3 to 1.7.5 by @dependabot in https://github.com/rclex/rclex/pull/289\n* Known issues to be addressed in the near future:\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n  * `publish/2` sometimes failed just after `create_publisher/3` in https://github.com/rclex/rclex/issues/212\n  * CI fails randomly at mix test in https://github.com/rclex/rclex/issues/246\n  * Bump to Iron Irwini, for Docker and Nerves environments in https://github.com/rclex/rclex/issues/228\n* Note in this release:\n  * This release is mainly as a record just prior to v0.10.0, which is scheduled to involve major changes\n  * We found there is a credo error in \"code-analysis\", but we decide to ignore it for now because we are soon going to v0.10.0! (if this is still an issue then, consider it at that time,,,","ref":"changelog.html#v0-9-3-on-23-feb-2024"},{"type":"extras","title":"v0.9.2 on 03 Oct 2023 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.9.1...v0.9.2\n\n* New features: none\n* Code Improvements/Fixes:\n  * add ROS_INCS path for using with Iron properly (fix #253) by @takasehideki in https://github.com/rclex/rclex/pull/256\n* Bumps:\n  * Bump credo from 1.7.0 to 1.7.1 by @dependabot in https://github.com/rclex/rclex/pull/254\n* Known issues to be addressed in the near future:\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n  * `publish/2` sometimes failed just after `create_publisher/3` in https://github.com/rclex/rclex/issues/212\n  * CI fails randomly at mix test in https://github.com/rclex/rclex/issues/246\n  * Bump to Iron Irwini, for Docker and Nerves environments in https://github.com/rclex/rclex/issues/228\n* Note in this release: none","ref":"changelog.html#v0-9-2-on-03-oct-2023"},{"type":"extras","title":"v0.9.1 on 12 Sep 2023 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.9.0...v0.9.1\n\n* New features:\n  * Experimental support for Iron Irwini by @takasehideki in https://github.com/rclex/rclex/pull/251\n* Code Improvements/Fixes: none\n* Bumps: none\n* Known issues to be addressed in the near future:\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n  * `publish/2` sometimes failed just after `create_publisher/3` in https://github.com/rclex/rclex/issues/212\n  * CI fails randomly at mix test in https://github.com/rclex/rclex/issues/246\n  * Bump to Iron Irwini, for Docker and Nerves environments in https://github.com/rclex/rclex/issues/228\n* Note in this release:\n  * Please welcome Iron Irwini as the experimental supported distribution for Rclex!! :tada:","ref":"changelog.html#v0-9-1-on-12-sep-2023"},{"type":"extras","title":"v0.9.0 on 11 Sep 2023 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.8.5...v0.9.0\n\n* New features:\n  * Support Humble (and format with Elixir 1.15.5) by @pojiro in https://github.com/rclex/rclex/pull/241\n  * Support humble, galactic Nerves by @pojiro in https://github.com/rclex/rclex/pull/244\n  * change the recommended environment and versions by @takasehideki in https://github.com/rclex/rclex/pull/247\n  * Add humble support to arm32v7_ros_distros by @pojiro in https://github.com/rclex/rclex/pull/248\n* Code Improvements/Fixes:\n  * Fix bug of `mix rclex.gen.msgs` by @pojiro in https://github.com/rclex/rclex/pull/236\n  * fix docs about ROS_DISTRO from `foxy` to `humble` by @takasehideki in https://github.com/rclex/rclex/pull/249\n* Bumps:\n  * Bump ex_doc from 0.29.4 to 0.30.6 by @dependabot in https://github.com/rclex/rclex/pull/234 https://github.com/rclex/rclex/pull/237 https://github.com/rclex/rclex/pull/238\n  * Bump dialyxir from 1.3.0 to 1.4.1 by @dependabot in https://github.com/rclex/rclex/pull/240\n  * Bump mix_test_watch from 1.1.0 to 1.1.1 by @dependabot in https://github.com/rclex/rclex/pull/242\n* Known issues to be addressed in the near future:\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n  * `publish/2` sometimes failed just after `create_publisher/3` in https://github.com/rclex/rclex/issues/212\n  * CI fails randomly at mix test in https://github.com/rclex/rclex/issues/246\n  * Bump to Iron Irwini in https://github.com/rclex/rclex/issues/228\n* Note in this release:\n  * Please welcome Humble Hawksbill (and Galactic Geochelone) as the new supported distribution for Rclex!! :tada:","ref":"changelog.html#v0-9-0-on-11-sep-2023"},{"type":"extras","title":"v0.8.5 on 05 Jun 2023 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.8.4...v0.8.5\n\n* New features:\n  * Adding handling for nested Message types from different Packages by @steve-at in https://github.com/rclex/rclex/pull/230\n* Code Improvements/Fixes: none\n* Bumps:\n  * Bump elixir_make from 0.7.6 to 0.7.7\n* Known issues to be addressed in the near future:\n  * `publish/2` sometimes failed just after `create_publisher/3` in https://github.com/rclex/rclex/issues/212\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Bump to Humble Hawksbill in https://github.com/rclex/rclex/issues/114\n  * Bump to Iron Irwini in https://github.com/rclex/rclex/issues/228\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n* Note in this release: none","ref":"changelog.html#v0-8-5-on-05-jun-2023"},{"type":"extras","title":"v0.8.4 on 11 Apr 2023 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.8.3...v0.8.4\n\n* New features: none\n* Code Improvements/Fixes:\n  * Fix typos by @kianmeng in https://github.com/rclex/rclex/pull/217\n* Bumps:\n  * Bump elixir_make from 0.7.1 to 0.7.6\n  * Bump ex_doc from 0.29.1 to 0.29.4\n  * Bump credo from 1.6.7 to 1.7.0\n  * Bump dialyxir from 1.2.0 to 1.3.0\n* Known issues to be addressed in the near future:\n  * `publish/2` sometimes failed just after `create_publisher/3` in https://github.com/rclex/rclex/issues/212\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Bump to Humble Hawksbill in https://github.com/rclex/rclex/issues/114\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n* Note in this release: none","ref":"changelog.html#v0-8-4-on-11-apr-2023"},{"type":"extras","title":"v0.8.3 on 12 Dec 2022 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.8.2...v0.8.3\n\n* New features:\n  * Add arm32v7 support to mix rclex.prep.ros2 by @pojiro in https://github.com/rclex/rclex/pull/210\n* Code Improvements/Fixes:\n  * improve doc about docker env by @takasehideki in https://github.com/rclex/rclex/pull/208\n  * Remove useless gitignore line by @pojiro in https://github.com/rclex/rclex/pull/211\n  * insert sleep before publishing on example code (see #212) by @takasehideki in https://github.com/rclex/rclex/pull/213\n* Bumps:\n  * Bump elixir_make from 0.7.0 to 0.7.1 by @dependabot in https://github.com/rclex/rclex/pull/209\n* Known issues to be addressed in the near future:\n  * `publish/2` sometimes failed just after `create_publisher/3` in https://github.com/rclex/rclex/issues/212\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Bump to Humble Hawksbill in https://github.com/rclex/rclex/issues/114\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n* Note in this release: none","ref":"changelog.html#v0-8-3-on-12-dec-2022"},{"type":"extras","title":"v0.8.2 on 03 Dec 2022 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.8.1...v0.8.2\n\n* New features: none\n* Code Improvements/Fixes:\n  * fix to check ROS_DIR by @takasehideki in https://github.com/rclex/rclex/pull/206\n* Bumps: none\n* Known issues to be addressed in the near future:\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Bump to Humble Hawksbill in https://github.com/rclex/rclex/issues/114\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n* Note in this release:\n  * This release only fixes a critical issue that existed in the previous release,,,","ref":"changelog.html#v0-8-2-on-03-dec-2022"},{"type":"extras","title":"v0.8.1 on 03 Dec 2022 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.8.0...v0.8.1\n\n* New features:\n  * Create docs for Use on Nerves and improve related mix tasks by @pojiro in https://github.com/rclex/rclex/pull/198\n* Code Improvements/Fixes:\n  * Change `raise` to `Mix.raise` to proper mix task error handling by @pojiro in https://github.com/rclex/rclex/pull/194\n  * Change Makefile's if statement to confirm ROS_DIR exists by @pojiro in https://github.com/rclex/rclex/pull/195\n  * Improve mix tasks usability by @pojiro in https://github.com/rclex/rclex/pull/196\n* Bumps:\n  * Bump ex_doc from 0.29.0 to 0.29.1 by @dependabot in https://github.com/rclex/rclex/pull/199\n  * Bump elixir_make from 0.6.3 to 0.7.0 by @dependabot in https://github.com/rclex/rclex/pull/200\n* Known issues to be addressed in the near future:\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Bump to Humble Hawksbill in https://github.com/rclex/rclex/issues/114\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n* Note in this release: none","ref":"changelog.html#v0-8-1-on-03-dec-2022"},{"type":"extras","title":"v0.8.0 on 01 Nov 2022 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.7.2...v0.8.0\n\n**Holy Shit! Rclex now works on Nerves as well!!** :tada:\n\n* New features:\n  * Refactor generate messages codes pojiro by @pojiro in https://github.com/rclex/rclex/pull/185\n  * refactor Makefile and msgs.ex by @pojiro in https://github.com/rclex/rclex/pull/192\n  * Feature add tasks to prepare ros2 resources by @pojiro in https://github.com/rclex/rclex/pull/190\n* Code Improvements/Fixes:\n  * Add docker command to mix test.watch section on README.md by @pojiro in https://github.com/rclex/rclex/pull/177\n  * Fix `mix deps.get` error on GitHub Actions by @s-hosoai in https://github.com/rclex/rclex/pull/178\n  * Fix multiple definition by @pojiro in https://github.com/rclex/rclex/pull/182\n  * Remove DASHING support from c source by @pojiro in https://github.com/rclex/rclex/pull/189\n  * Remove unused rclex_gen_msgs from mix.lock by @pojiro in https://github.com/rclex/rclex/pull/191\n* Bumps:\n  *  `ex_doc` from 0.28.6 to 0.29.0 by @dependabot in https://github.com/rclex/rclex/pull/184\n* Known issues to be addressed in the near future:\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Bump to Humble Hawksbill in https://github.com/rclex/rclex/issues/114\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n* Note in this release:\n  * set supported/tested elixir version to above 1.12 by @takasehideki in https://github.com/rclex/rclex/pull/186","ref":"changelog.html#v0-8-0-on-01-nov-2022"},{"type":"extras","title":"v0.7.2 on 22 Sep 2022 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.7.1...v0.7.2\n\n* New features: none\n* Code Improvements/Fixes:\n  * change the recommended env and target versions for GitHub Actions CI by @takasehideki in https://github.com/rclex/rclex/pull/173\n  * Enable Dialyzer on GitHub Actions (remove uncheck and ignore exit options) by @s-hosoai in https://github.com/rclex/rclex/pull/165\n  * elinimate errors in `mix dialyzer` on GHA (fix #174) by @takasehideki in https://github.com/rclex/rclex/pull/175\n* Bumps:\n  * `dialyxir` from 1.1.0 to 1.2.0 in https://github.com/rclex/rclex/pull/166\n  *  `ex_doc` from 0.28.4 to 0.28.5 in https://github.com/rclex/rclex/pull/168\n  * `credo` from 1.6.5 to 1.6.7 by https://github.com/rclex/rclex/pull/169\n* Known issues to be addressed in the near future:\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Bump to Humble Hawksbill in https://github.com/rclex/rclex/issues/114\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n* Note in this release:\n  * The recommended environment is changed to the following versions\n    * Ubuntu 20.04.2 LTS (Focal Fossa)\n    * ROS 2 [Foxy Fitzroy](https://docs.ros.org/en/foxy/Releases/Release-Foxy-Fitzroy.html)\n    * Elixir 1.13.4-otp-25\n    * Erlang/OTP 25.0.3","ref":"changelog.html#v0-7-2-on-22-sep-2022"},{"type":"extras","title":"v0.7.1 on 21 Sep 2022 - CHANGELOG","doc":"**Full Changelog**: https://github.com/rclex/rclex/compare/v0.7.0...v0.7.1\n\n* New Contributors: @pojiro :tada:\n* New features:\n  * Improve unit test environment on local dev machine by @pojiro in https://github.com/rclex/rclex/pull/131\n* Code Improvements/Fixes:\n  * Enrich doc and specs with the awesome contributions by @pojiro (e.g., in https://github.com/rclex/rclex/pull/121)\n  * Enrich unit tests with the awesome contributions by @pojiro (e.g., in https://github.com/rclex/rclex/pull/136)\n  * Improve credo config, .credo.exs by @pojiro in https://github.com/rclex/rclex/pull/120\n  * exclude auto-generated files format by @pojiro in https://github.com/rclex/rclex/pull/135\n  * refactor Rclex.ResourceServer.call_nifs_rcl_node_init/5 by @pojiro in https://github.com/rclex/rclex/pull/147\n  * fix node name bug, when it attributes a namespace (and also fix #142) by @pojiro in https://github.com/rclex/rclex/pull/149\n  * Remove KeepSub module which is unused (also fix dialyzer error) by @s-hosoai in https://github.com/rclex/rclex/pull/164\n  * Improve README by @takasehideki in https://github.com/rclex/rclex/pull/171\n* Bumps:\n  * `credo` from 1.6.4 to 1.6.5 in https://github.com/rclex/rclex/pull/162\n* Known issues to be addressed in the near future:\n  * Lock `git_hooks` to 0.6.5 due to its issue in https://github.com/rclex/rclex/issues/138\n  * Bump to Humble Hawksbill in https://github.com/rclex/rclex/issues/114\n  * Release rcl nif resources when GerServer terminates in https://github.com/rclex/rclex/issues/160\n* Note in this release:\n  * After long consideration, we have decided to end the support for Dashing as the target environment 6ae367d","ref":"changelog.html#v0-7-1-on-21-sep-2022"},{"type":"extras","title":"v0.7.0 on 27 May 2022 - CHANGELOG","doc":"* New features: none\n* Code Improvements/Fixes:\n  * Refactoring to simplify implementation by @s-hosoai in https://github.com/rclex/rclex/pull/118\n    * rename and simplify functions\n    * delete comment out functions\n    * change NIF exception handling\n    * add @spac and @impl\n    * refine tests\n* Bumps: none\n* Known issues:\n  * `rclex_connection_tests` becomes failed on Dashing from v0.6.0_rc #89\n  * `Rclex.initialize_msg/0` is undefined or private in `KeepSub.sub_task_start/2` #104\n* Full Changelog: https://github.com/rclex/rclex/compare/v0.6.2...v0.7.0","ref":"changelog.html#v0-7-0-on-27-may-2022"},{"type":"extras","title":"v0.6.2 on 25 May 2022 - CHANGELOG","doc":"* Please welcome @s-hosoai as a new maintainer!\n* New features: none\n* Code Improvements/Fixes:\n  * Add simple pub sub test by @s-hosoai in https://github.com/rclex/rclex/pull/113\n  * fix job_queue length condition (fix #112) by @s-hosoai in https://github.com/rclex/rclex/pull/115\n  * remove Dashing from CI targets by @takasehideki in https://github.com/rclex/rclex/pull/116\n* Bumps:\n  * `ex_doc` to 0.28.4 #110\n* Known issues:\n  * `rclex_connection_tests` becomes failed on Dashing from v0.6.0_rc #89\n  * `Rclex.initialize_msg/0` is undefined or private in `KeepSub.sub_task_start/2` #104\n* Full Changelog: https://github.com/rclex/rclex/compare/v0.6.1...v0.6.2","ref":"changelog.html#v0-6-2-on-25-may-2022"},{"type":"extras","title":"v0.6.1 on 22 Mar 2022 - CHANGELOG","doc":"- New features: none\n- Code Improvements/Fixes:\n  - include packages.txt and template file to hex package #107\n- Bumps: none\n- Known issues:\n  - `rclex_connection_tests` becomes failed on Dashing from v0.6.0_rc #89\n  - `Rclex.initialize_msg/0` is undefined or private in `KeepSub.sub_task_start/2` #104\n- Full Changelog: https://github.com/rclex/rclex/compare/v0.6.0...v0.6.1","ref":"changelog.html#v0-6-1-on-22-mar-2022"},{"type":"extras","title":"v0.6.0 on 17 Mar 2022 - CHANGELOG","doc":"- New features:\n  - support custom msgtype!! #87 #98\n- Code Improvements/Fixes:\n  - Enhance README #102\n- Bumps:\n  - `ex_doc` to 0.28.2 #99\n  - `credo` to 1.6.4 #100\n- Known issues:\n  - `rclex_connection_tests` becomes failed on Dashing from v0.6.0_rc #89\n  - `Rclex.initialize_msg/0` is undefined or private in `KeepSub.sub_task_start/2` #104\n- Full Changelog: https://github.com/rclex/rclex/compare/v0.5.3...v0.6.0","ref":"changelog.html#v0-6-0-on-17-mar-2022"},{"type":"extras","title":"v0.5.3 on 22 Feb 2022 - CHANGELOG","doc":"- New features:\n  - Add following APIs #92 \n    - `create_singlenode_with_executor_setting/3`\n      - can specify `executor_setting` in addition to args in `create_singlenode/3`\n      - `{queue_length}` means the maximum length of `job_queue` under the created nodes\n      - `change_order` (in `{queue_length, change_order}`) means a function that adjusts the execution order of `job_exe`\n    - `create_nodes_with_executor_setting/4`, `create_timer_with_executor_setting/5` and `create_timer_with_executor_setting/6`: same with the above\n- Code Improvements/Fixes: none\n- Bumps:\n  - `ex_doc` to 0.28.1 #96\n  - `credo` to 1.6.3 #91\n- Known issues:\n  - `mix test` sometimes fails, but we don't think it will affect the behavior #68\n- Full Changelog: https://github.com/rclex/rclex/compare/v0.5.2...v0.5.3","ref":"changelog.html#v0-5-3-on-22-feb-2022"},{"type":"extras","title":"v0.5.2 on 21 Jan 2022 - CHANGELOG","doc":"- New features:\n  - Add timer name in args of `create_timer/4` and `create_timer/5` to treat timer ID ddf99cf\n  - Implement `ResourceServer` module #83\n    - `JobExecutor` and `JobQueue` will be created for each node and timer\n    - `Executor` has been obsoleted and changed to the above feature\n- Code Improvements/Fixes:\n  - change wait time 50 to 5 milliseconds #76\n  - change docker tags for CI test #78\n- Bumps:\n  - `ex_doc` to 0.27.3 #80\n  - `credo` to 1.6.2 #82\n- Known issues:\n  - `mix test` sometimes fails, but we don't think it will affect the behavior #68\n- Full Changelog: https://github.com/rclex/rclex/compare/v0.5.1...v0.5.2","ref":"changelog.html#v0-5-2-on-21-jan-2022"},{"type":"extras","title":"v0.5.1 on 30 Nov 2021 - CHANGELOG","doc":"- New features:\n  - Implement `Timer.terminate/2` [2915de5](https://github.com/rclex/rclex/commit/2915de5a7bdaa3ca22b56c7900d03a9931e057f9)\n- Code Improvements/Fixes:\n  - Change filename to snake_case according to follow ElixirStyleGuide #72 \n  - Some minor refactoring to remove boring warning in `mix compile` #73\n- Bumps:\n  - `ex_doc` to 0.26.0 #71\n  - `credo` to 1.6.1 #70\n- Known issues:\n  - `mix test` sometimes fails, but we don't think it will affect the behavior #68\n- Full Changelog: https://github.com/rclex/rclex/compare/v0.5.0...v0.5.1","ref":"changelog.html#v0-5-1-on-30-nov-2021"},{"type":"extras","title":"v0.5.0 on 01 Nov 2021 - CHANGELOG","doc":"- New features:\n  - Implement `Executor` module by using GenServer #61 #67\n- Code Improvements/Fixes:\n  - Hide NIF functions from users #54 #55\n- Bumps:\n  - `ex_doc` to 0.25.5 #63\n  - `elixir_make` to 0.6.3 #62\n- Known issues:\n  - `mix test` sometimes fails, but we don't think it will affect the behavior #68\n- Full Changelog: https://github.com/rclex/rclex/compare/v0.4.1...v0.5.0","ref":"changelog.html#v0-5-0-on-01-nov-2021"},{"type":"extras","title":"v0.4.1 on 24 Jul 2021 - CHANGELOG","doc":"- New features:\n  - Implement `rcl_node_get_name/1` and `rcl_get_topic_names_and_types/3` #42\n- Code Improvements/Fixes:\n  - Improve code according to the advice from Credo #41 \n  - Use DEBUG_PRINTF and Logger to control print message in library #46 #23 #24\n  - Change the method to obtain ROS_DIR with `which ros2` #38\n  - Add and apply Artistic Style for C source (mix format) #45\n- Enhancements:\n  - Introduce `mix credo` on GHA #48\n  - Create GHA to publish to Hex when tags released #40\n  - Separate ci.yml #49\n  - Improve timing of connection tests [rclex/rclex_connection_tests#12](https://github.com/rclex/rclex_connection_tests/pull/12)\n- Bumps:\n  - `ex_doc` from 0.24.2 to 0.25.0 #47\n- Full Changelog: https://github.com/rclex/rclex/compare/v0.4.0...v0.4.1","ref":"changelog.html#v0-4-1-on-24-jul-2021"},{"type":"extras","title":"v0.4.0 on 8 Jun 2021 - CHANGELOG","doc":"- Please welcome @kebus426 as a new maintainer! \n- Support for [ROS 2 Foxy Fitzroy](https://index.ros.org/doc/ros2/Releases/Release-Foxy-Fitzroy/)!! #32 :tada:\n- Recommended environment is now Ubuntu 20.04.2 LTS / ROS 2 Foxy / Elixir 1.11.2-otp-23 / Erlang/OTP 23.3.1\n  - also work well on Ubuntu 18.04.5 LTS and Dashing Diademata\n- Introduce automatic test a.k.a CI works on [GitHub Actions](https://github.com/rclex/rclex/actions) #13 #25 #31 \n  - Please also check [rclex_connection_tests](https://github.com/rclex/rclex_connection_tests) and [rclex_docker on Docker Hub](https://hub.docker.com/r/rclex/rclex_docker) for more details\n  - Note that CI sometimes fails due to the performance of GHA runner #28 \n- Implement subsucribe_stop/2 #30\n- Fix bug on timer_loop/4 #29 #21 \n- Create [rclex Organization](https://github.com/rclex) and change source URL #18\n- Full Changelog: https://github.com/rclex/rclex/compare/v0.3.1...v0.4.0","ref":"changelog.html#v0-4-0-on-8-jun-2021"},{"type":"extras","title":"v0.3.1 on 4 Jul 2020 - CHANGELOG","doc":"- Translate README from Japanese to English #11","ref":"changelog.html#v0-3-1-on-4-jul-2020"},{"type":"extras","title":"v0.3.0 on 26 Jun 2020 - CHANGELOG","doc":"- Change module name to Rclex #8","ref":"changelog.html#v0-3-0-on-26-jun-2020"},{"type":"extras","title":"v0.2.0 on 24 Feb 2020 - CHANGELOG","doc":"- Publish this package on hex.pm\n  - You can now use this repository as the Hex package\n- Refactor source tree\n  - Adjust elixir_make to generate rclex.so to priv/\n  - Eliminate Timex\n- Apply mix format\n- Write README doc, only by Japanese (sorry,,,)","ref":"changelog.html#v0-2-0-on-24-feb-2020"},{"type":"extras","title":"v0.1.0 on 24 Feb 2020 - CHANGELOG","doc":"First publication","ref":"changelog.html#v0-1-0-on-24-feb-2020"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}